aboutsummaryrefslogtreecommitdiff
path: root/backends/symbian
diff options
context:
space:
mode:
Diffstat (limited to 'backends/symbian')
-rw-r--r--backends/symbian/src/SymbianActions.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/backends/symbian/src/SymbianActions.cpp b/backends/symbian/src/SymbianActions.cpp
index e42f134ada..1dc8dd41c4 100644
--- a/backends/symbian/src/SymbianActions.cpp
+++ b/backends/symbian/src/SymbianActions.cpp
@@ -139,9 +139,9 @@ void SymbianActions::initInstanceGame() {
// Save
if (is_simon || is_gob)
_action_enabled[ACTION_SAVE] = false;
- else if (is_queen) {
+ else if (is_queen || is_ite) {
_action_enabled[ACTION_SAVE] = true;
- _key_action[ACTION_SAVE].setAscii(SDLK_F1); // F1 key for FOTAQ or F5??!?
+ _key_action[ACTION_SAVE].setAscii(SDLK_F1); // F1 key for FOTAQ and ITE
} else if (is_sky) {
_action_enabled[ACTION_SAVE] = true;
_key_action[ACTION_SAVE].setAscii(63);